@@ -4,7 +4,8 @@ from ._awgn import (awgn,
                     wgn_with_snr,
                     signal_like_noise)
 
-from ._auxiliary import pad_to_power_of_2,pad_noises
+from ._auxiliary import (pad_to_power_of_2,
+                         pad_noises)
 
 from ._types import(fixpoint,
                     is_1d,
@@ -17,8 +18,6 @@ from ._probe import probe, probe_filter
 
 from ._findpeaks import findpeaks
 
-from ..operators import *
-
 from ._barycenter import barycenter
 
 from ._math import(cexp,
@@ -29,3 +28,9 @@ from ._math import(cexp,
                    cross_subsets,
                    corcof)
 
+from ._geometry import (calc_line,
+                        flip_vector,
+                        ols_line,
+                        piecewise_ols_line)
+
+from ..operators import *
